==> moment-timezone.js_0.5.16+dfsg1.orig.tar.xz: moment-timezone-0.5.16/tests/zones/w-su.js <==
"use strict";

var helpers = require("../helpers/helpers");

exports["W-SU"] = {
	"1916" : helpers.makeTestYear("W-SU", [
		["1916-07-02T21:29:42+00:00", "23:59:59", "MMT", -9017 / 60],
		["1916-07-02T21:29:43+00:00", "00:01:02", "MMT", -9079 / 60]
	]),

	"1917" : helpers.makeTestYear("W-SU", [
		["1917-07-01T20:28:40+00:00", "22:59:59", "MMT", -9079 / 60],
		["1917-07-01T20:28:41+00:00", "00:00:00", "MST", -12679 / 60],
		["1917-12-27T20:28:40+00:00", "23:59:59", "MST", -12679 / 60],
		["1917-12-27T20:28:41+00:00", "23:00:00", "MMT", -9079 / 60]
	]),

	"1918" : helpers.makeTestYear("W-SU", [
		["1918-05-31T19:28:40+00:00", "21:59:59", "MMT", -9079 / 60],
		["1918-05-31T19:28:41+00:00", "00:00:00", "MDST", -16279 / 60],
		["1918-09-15T20:28:40+00:00", "00:59:59", "MDST", -16279 / 60],
		["1918-09-15T20:28:41+00:00", "00:00:00", "MST", -12679 / 60]
	]),

	"1919" : helpers.makeTestYear("W-SU", [
		["1919-05-31T19:28:40+00:00", "22:59:59", "MST", -12679 / 60],
		["1919-05-31T19:28:41+00:00", "00:00:00", "MDST", -16279 / 60],
		["1919-06-30T23:59:59+00:00", "04:31:18", "MDST", -16279 / 60],
		["1919-07-01T00:00:00+00:00", "04:00:00", "MSD", -240],
		["1919-08-15T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1919-08-15T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1921" : helpers.makeTestYear("W-SU", [
		["1921-02-14T19:59:59+00:00", "22:59:59", "MSK", -180],
		["1921-02-14T20:00:00+00:00", "00:00:00", "MSD", -240],
		["1921-03-20T18:59:59+00:00", "22:59:59", "MSD", -240],
		["1921-03-20T19:00:00+00:00", "00:00:00", "+05", -300],
		["1921-08-31T18:59:59+00:00", "23:59:59", "+05", -300],
		["1921-08-31T19:00:00+00:00", "23:00:00", "MSD", -240],
		["1921-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1921-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1922" : helpers.makeTestYear("W-SU", [
		["1922-09-30T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1922-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1930" : helpers.makeTestYear("W-SU", [
		["1930-06-20T21:59:59+00:00", "23:59:59", "EET", -120],
		["1930-06-20T22:00:00+00:00", "01:00:00", "MSK", -180]
	]),

	"1981" : helpers.makeTestYear("W-SU", [
		["1981-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1981-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1981-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1981-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1982" : helpers.makeTestYear("W-SU", [
		["1982-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1982-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1982-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1982-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1983" : helpers.makeTestYear("W-SU", [
		["1983-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1983-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1983-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1983-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1984" : helpers.makeTestYear("W-SU", [
		["1984-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1984-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1984-09-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1984-09-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1985" : helpers.makeTestYear("W-SU", [
		["1985-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1985-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1985-09-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1985-09-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1986" : helpers.makeTestYear("W-SU", [
		["1986-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1986-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1986-09-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1986-09-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1987" : helpers.makeTestYear("W-SU", [
		["1987-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1987-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1987-09-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1987-09-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1988" : helpers.makeTestYear("W-SU", [
		["1988-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1988-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1988-09-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1988-09-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1989" : helpers.makeTestYear("W-SU", [
		["1989-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1989-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1989-09-23T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1989-09-23T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1990" : helpers.makeTestYear("W-SU", [
		["1990-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1990-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1990-09-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1990-09-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1991" : helpers.makeTestYear("W-SU", [
		["1991-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1991-03-30T23:00:00+00:00", "02:00:00", "EEST", -180],
		["1991-09-28T23:59:59+00:00", "02:59:59", "EEST", -180],
		["1991-09-29T00:00:00+00:00", "02:00:00", "EET", -120]
	]),

	"1992" : helpers.makeTestYear("W-SU", [
		["1992-01-18T23:59:59+00:00", "01:59:59", "EET", -120],
		["1992-01-19T00:00:00+00:00", "03:00:00", "MSK", -180],
		["1992-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1992-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1992-09-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1992-09-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1993" : helpers.makeTestYear("W-SU", [
		["1993-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1993-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1993-09-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1993-09-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1994" : helpers.makeTestYear("W-SU", [
		["1994-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1994-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1994-09-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1994-09-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1995" : helpers.makeTestYear("W-SU", [
		["1995-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1995-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1995-09-23T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1995-09-23T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1996" : helpers.makeTestYear("W-SU", [
		["1996-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1996-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1996-10-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1996-10-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1997" : helpers.makeTestYear("W-SU", [
		["1997-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1997-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1997-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1997-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1998" : helpers.makeTestYear("W-SU", [
		["1998-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1998-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1998-10-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1998-10-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1999" : helpers.makeTestYear("W-SU", [
		["1999-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1999-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1999-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1999-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2000" : helpers.makeTestYear("W-SU", [
		["2000-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2000-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2000-10-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2000-10-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2001" : helpers.makeTestYear("W-SU", [
		["2001-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2001-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2001-10-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2001-10-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2002" : helpers.makeTestYear("W-SU", [
		["2002-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2002-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2002-10-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2002-10-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2003" : helpers.makeTestYear("W-SU", [
		["2003-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2003-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2003-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2003-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2004" : helpers.makeTestYear("W-SU", [
		["2004-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2004-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2004-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2004-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2005" : helpers.makeTestYear("W-SU", [
		["2005-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2005-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2005-10-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2005-10-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2006" : helpers.makeTestYear("W-SU", [
		["2006-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2006-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2006-10-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2006-10-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2007" : helpers.makeTestYear("W-SU", [
		["2007-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2007-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2007-10-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2007-10-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2008" : helpers.makeTestYear("W-SU", [
		["2008-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2008-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2008-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2008-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2009" : helpers.makeTestYear("W-SU", [
		["2009-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2009-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2009-10-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2009-10-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2010" : helpers.makeTestYear("W-SU", [
		["2010-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2010-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2010-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2010-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2011" : helpers.makeTestYear("W-SU", [
		["2011-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2011-03-26T23:00:00+00:00", "03:00:00", "MSK", -240]
	]),

	"2014" : helpers.makeTestYear("W-SU", [
		["2014-10-25T21:59:59+00:00", "01:59:59", "MSK", -240],
		["2014-10-25T22:00:00+00:00", "01:00:00", "MSK", -180]
	])
};

==> moment-timezone.js_0.5.23+dfsg1.orig.tar.xz: moment-timezone-0.5.23/tests/zones/w-su.js <==
"use strict";

var helpers = require("../helpers/helpers");

exports["W-SU"] = {

	"guess:by:offset" : helpers.makeTestGuess("W-SU", { offset: true, expect: "Europe/Moscow" }),

	"guess:by:abbr" : helpers.makeTestGuess("W-SU", { abbr: true, expect: "Europe/Moscow" }),

	"1916" : helpers.makeTestYear("W-SU", [
		["1916-07-02T21:29:42+00:00", "23:59:59", "MMT", -9017 / 60],
		["1916-07-02T21:29:43+00:00", "00:01:02", "MMT", -9079 / 60]
	]),

	"1917" : helpers.makeTestYear("W-SU", [
		["1917-07-01T20:28:40+00:00", "22:59:59", "MMT", -9079 / 60],
		["1917-07-01T20:28:41+00:00", "00:00:00", "MST", -12679 / 60],
		["1917-12-27T20:28:40+00:00", "23:59:59", "MST", -12679 / 60],
		["1917-12-27T20:28:41+00:00", "23:00:00", "MMT", -9079 / 60]
	]),

	"1918" : helpers.makeTestYear("W-SU", [
		["1918-05-31T19:28:40+00:00", "21:59:59", "MMT", -9079 / 60],
		["1918-05-31T19:28:41+00:00", "00:00:00", "MDST", -16279 / 60],
		["1918-09-15T20:28:40+00:00", "00:59:59", "MDST", -16279 / 60],
		["1918-09-15T20:28:41+00:00", "00:00:00", "MST", -12679 / 60]
	]),

	"1919" : helpers.makeTestYear("W-SU", [
		["1919-05-31T19:28:40+00:00", "22:59:59", "MST", -12679 / 60],
		["1919-05-31T19:28:41+00:00", "00:00:00", "MDST", -16279 / 60],
		["1919-06-30T23:59:59+00:00", "04:31:18", "MDST", -16279 / 60],
		["1919-07-01T00:00:00+00:00", "04:00:00", "MSD", -240],
		["1919-08-15T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1919-08-15T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1921" : helpers.makeTestYear("W-SU", [
		["1921-02-14T19:59:59+00:00", "22:59:59", "MSK", -180],
		["1921-02-14T20:00:00+00:00", "00:00:00", "MSD", -240],
		["1921-03-20T18:59:59+00:00", "22:59:59", "MSD", -240],
		["1921-03-20T19:00:00+00:00", "00:00:00", "+05", -300],
		["1921-08-31T18:59:59+00:00", "23:59:59", "+05", -300],
		["1921-08-31T19:00:00+00:00", "23:00:00", "MSD", -240],
		["1921-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1921-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1922" : helpers.makeTestYear("W-SU", [
		["1922-09-30T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1922-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1930" : helpers.makeTestYear("W-SU", [
		["1930-06-20T21:59:59+00:00", "23:59:59", "EET", -120],
		["1930-06-20T22:00:00+00:00", "01:00:00", "MSK", -180]
	]),

	"1981" : helpers.makeTestYear("W-SU", [
		["1981-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1981-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1981-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1981-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1982" : helpers.makeTestYear("W-SU", [
		["1982-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1982-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1982-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1982-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1983" : helpers.makeTestYear("W-SU", [
		["1983-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1983-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1983-09-30T19:59:59+00:00", "23:59:59", "MSD", -240],
		["1983-09-30T20:00:00+00:00", "23:00:00", "MSK", -180]
	]),

	"1984" : helpers.makeTestYear("W-SU", [
		["1984-03-31T20:59:59+00:00", "23:59:59", "MSK", -180],
		["1984-03-31T21:00:00+00:00", "01:00:00", "MSD", -240],
		["1984-09-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1984-09-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1985" : helpers.makeTestYear("W-SU", [
		["1985-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1985-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1985-09-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1985-09-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1986" : helpers.makeTestYear("W-SU", [
		["1986-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1986-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1986-09-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1986-09-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1987" : helpers.makeTestYear("W-SU", [
		["1987-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1987-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1987-09-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1987-09-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1988" : helpers.makeTestYear("W-SU", [
		["1988-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1988-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1988-09-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1988-09-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1989" : helpers.makeTestYear("W-SU", [
		["1989-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1989-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1989-09-23T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1989-09-23T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1990" : helpers.makeTestYear("W-SU", [
		["1990-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1990-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1990-09-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1990-09-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1991" : helpers.makeTestYear("W-SU", [
		["1991-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1991-03-30T23:00:00+00:00", "02:00:00", "EEST", -180],
		["1991-09-28T23:59:59+00:00", "02:59:59", "EEST", -180],
		["1991-09-29T00:00:00+00:00", "02:00:00", "EET", -120]
	]),

	"1992" : helpers.makeTestYear("W-SU", [
		["1992-01-18T23:59:59+00:00", "01:59:59", "EET", -120],
		["1992-01-19T00:00:00+00:00", "03:00:00", "MSK", -180],
		["1992-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1992-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1992-09-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1992-09-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1993" : helpers.makeTestYear("W-SU", [
		["1993-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1993-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1993-09-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1993-09-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1994" : helpers.makeTestYear("W-SU", [
		["1994-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1994-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1994-09-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1994-09-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1995" : helpers.makeTestYear("W-SU", [
		["1995-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1995-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1995-09-23T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1995-09-23T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1996" : helpers.makeTestYear("W-SU", [
		["1996-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1996-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1996-10-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1996-10-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1997" : helpers.makeTestYear("W-SU", [
		["1997-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1997-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1997-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1997-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1998" : helpers.makeTestYear("W-SU", [
		["1998-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1998-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1998-10-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1998-10-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"1999" : helpers.makeTestYear("W-SU", [
		["1999-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["1999-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["1999-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["1999-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2000" : helpers.makeTestYear("W-SU", [
		["2000-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2000-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2000-10-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2000-10-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2001" : helpers.makeTestYear("W-SU", [
		["2001-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2001-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2001-10-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2001-10-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2002" : helpers.makeTestYear("W-SU", [
		["2002-03-30T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2002-03-30T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2002-10-26T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2002-10-26T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2003" : helpers.makeTestYear("W-SU", [
		["2003-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2003-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2003-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2003-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2004" : helpers.makeTestYear("W-SU", [
		["2004-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2004-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2004-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2004-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2005" : helpers.makeTestYear("W-SU", [
		["2005-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2005-03-26T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2005-10-29T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2005-10-29T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2006" : helpers.makeTestYear("W-SU", [
		["2006-03-25T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2006-03-25T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2006-10-28T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2006-10-28T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2007" : helpers.makeTestYear("W-SU", [
		["2007-03-24T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2007-03-24T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2007-10-27T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2007-10-27T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2008" : helpers.makeTestYear("W-SU", [
		["2008-03-29T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2008-03-29T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2008-10-25T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2008-10-25T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2009" : helpers.makeTestYear("W-SU", [
		["2009-03-28T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2009-03-28T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2009-10-24T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2009-10-24T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2010" : helpers.makeTestYear("W-SU", [
		["2010-03-27T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2010-03-27T23:00:00+00:00", "03:00:00", "MSD", -240],
		["2010-10-30T22:59:59+00:00", "02:59:59", "MSD", -240],
		["2010-10-30T23:00:00+00:00", "02:00:00", "MSK", -180]
	]),

	"2011" : helpers.makeTestYear("W-SU", [
		["2011-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
		["2011-03-26T23:00:00+00:00", "03:00:00", "MSK", -240]
	])
};
